@@ -4,7 +4,7 @@ from ensmallen import Graph, express_measures
 import numpy as np
 import pandas as pd
 import time
-from userinput.utils import closest
+from userinput.utils import must_be_in_set
 from tqdm.auto import trange, tqdm
 from embiggen.utils.abstract_models.list_formatting import format_list
 from cache_decorator import Cache
@@ -239,17 +239,11 @@ class AbstractClassifierModel(AbstractModel):
                 node_feature.set_random_state(random_state)
 
             if smoke_test:
-                node_feature = node_feature.__class__(
-                    **node_feature.smoke_test_parameters()
-                )
+                node_feature = node_feature.into_smoke_test()
 
             node_feature = node_feature.fit_transform(
                 graph=graph,
-                return_dataframe=False,
-                # If this is an Ensmallen model, we can enable the verbosity
-                # as it will only show up in the jupyter kernel and it won't bother the
-                # other loading bars.
-                verbose="Ensmallen" == node_feature.library_name()
+                return_dataframe=False
             )
 
         if isinstance(node_feature, EmbeddingResult):
@@ -442,14 +436,11 @@ class AbstractClassifierModel(AbstractModel):
                 node_type_feature.set_random_state(random_state)
 
             if smoke_test:
-                node_type_feature = node_type_feature.__class__(
-                    **node_type_feature.smoke_test_parameters()
-                )
+                node_type_feature = node_type_feature.into_smoke_test()
 
             node_type_feature = node_type_feature.fit_transform(
                 graph=graph,
                 return_dataframe=False,
-                verbose=False
             )
 
         if isinstance(node_type_feature, EmbeddingResult):
@@ -642,14 +633,11 @@ class AbstractClassifierModel(AbstractModel):
                 edge_feature.set_random_state(random_state)
 
             if smoke_test:
-                edge_feature = edge_feature.__class__(
-                    **edge_feature.smoke_test_parameters()
-                )
+                edge_feature = edge_feature.into_smoke_test()
 
             edge_feature = edge_feature.fit_transform(
                 graph=graph,
                 return_dataframe=False,
-                verbose=False
             )
 
         if isinstance(edge_feature, EmbeddingResult):
@@ -1107,12 +1095,10 @@ class AbstractClassifierModel(AbstractModel):
         holdouts_kwargs: Dict[str, Any]
             The kwargs to be forwarded to the holdout method.
         """
-        raise ValueError(
-            f"The requested evaluation schema `{evaluation_schema}` "
-            f"is not available in model for task {cls.task_name()} "
-            f"Did you mean {closest(evaluation_schema, cls.get_available_evaluation_schemas())}? "
-            "The available evaluation schemas "
-            f"are: {format_list(cls.get_available_evaluation_schemas())}."
+        must_be_in_set(
+            evaluation_schema,
+            cls.get_available_evaluation_schemas(),
+            f"evaluation schema for {cls.task_name()} and model {cls.model_name()}"
         )
 
     def _evaluate(
